altos: Switch ao_config.c __xdata to __pdata
[fw/altos] / src / ao.h
index 08f45275fd4e51e34d3b92a2f738ea786d587782..8836a286b05fab25d5e720cad8c98f4ea37c85a2 100644 (file)
--- a/src/ao.h
+++ b/src/ao.h
@@ -367,10 +367,10 @@ enum ao_cmd_status {
        ao_cmd_syntax_error = 2,
 };
 
-extern __xdata uint16_t ao_cmd_lex_i;
-extern __xdata uint32_t ao_cmd_lex_u32;
-extern __xdata char    ao_cmd_lex_c;
-extern __xdata enum ao_cmd_status ao_cmd_status;
+extern __pdata uint16_t ao_cmd_lex_i;
+extern __pdata uint32_t ao_cmd_lex_u32;
+extern __pdata char    ao_cmd_lex_c;
+extern __pdata enum ao_cmd_status ao_cmd_status;
 
 void
 ao_cmd_lex(void);
@@ -395,7 +395,7 @@ ao_match_word(__code char *word);
 
 struct ao_cmds {
        void            (*func)(void);
-       const char      *help;
+       __code char     *help;
 };
 
 void
@@ -535,7 +535,7 @@ extern __pdata uint32_t ao_log_current_pos;
 extern __pdata uint32_t ao_log_end_pos;
 extern __pdata uint32_t ao_log_start_pos;
 extern __xdata uint8_t ao_log_running;
-extern __xdata enum flight_state ao_log_state;
+extern __pdata enum flight_state ao_log_state;
 
 /* required functions from the underlying log system */
 
@@ -803,13 +803,13 @@ extern __data uint8_t     ao_sample_adc;          /* Ring position of last processed sample
 extern __pdata int16_t ao_sample_accel;        /* most recent accel sensor reading */
 #endif
 
-extern __xdata int16_t ao_ground_pres;         /* startup pressure */
-extern __xdata int16_t ao_ground_height;       /* MSL of ao_ground_pres */
+extern __pdata int16_t ao_ground_pres;         /* startup pressure */
+extern __pdata int16_t ao_ground_height;       /* MSL of ao_ground_pres */
 
 #if HAS_ACCEL
-extern __xdata int16_t ao_ground_accel;        /* startup acceleration */
-extern __xdata int16_t         ao_accel_2g;            /* factory accel calibration */
-extern __xdata int32_t ao_accel_scale;         /* sensor to m/s² conversion */
+extern __pdata int16_t ao_ground_accel;        /* startup acceleration */
+extern __pdata int16_t         ao_accel_2g;            /* factory accel calibration */
+extern __pdata int32_t ao_accel_scale;         /* sensor to m/s² conversion */
 #endif
 
 void ao_sample_init(void);
@@ -1018,8 +1018,9 @@ struct ao_telemetry_configuration {
        uint16_t        flight;                         /*  6 flight number */
        uint8_t         config_major;                   /*  8 Config major version */
        uint8_t         config_minor;                   /*  9 Config minor version */
-       uint16_t        main_deploy;                    /* 10 Main deploy alt in meters */
-       uint32_t        flight_log_max;                 /* 12 Maximum flight log size in bytes */
+       uint16_t        apogee_delay;                   /* 10 Apogee deploy delay in seconds */
+       uint16_t        main_deploy;                    /* 12 Main deploy alt in meters */
+       uint16_t        flight_log_max;                 /* 14 Maximum flight log size in kB */
        char            callsign[AO_MAX_CALLSIGN];      /* 16 Radio operator identity */
        char            version[AO_MAX_VERSION];        /* 24 Software version */
        /* 32 */
@@ -1098,7 +1099,7 @@ union ao_telemetry_all {
 #define AO_GPS_DATE_VALID      (1 << 6)
 #define AO_GPS_COURSE_VALID    (1 << 7)
 
-extern __xdata uint16_t ao_gps_tick;
+extern __pdata uint16_t ao_gps_tick;
 extern __xdata uint8_t ao_gps_mutex;
 extern __xdata struct ao_telemetry_location ao_gps_data;
 extern __xdata struct ao_telemetry_satellite ao_gps_tracking_data;
@@ -1310,8 +1311,8 @@ struct ao_stdio {
 };
 
 extern __xdata struct ao_stdio ao_stdios[];
-extern __data int8_t ao_cur_stdio;
-extern __data int8_t ao_num_stdios;
+extern __pdata int8_t ao_cur_stdio;
+extern __pdata int8_t ao_num_stdios;
 
 void
 flush(void);